dist2AllEuclid: Distances to all data points

Description Usage Arguments Value Author(s)

Description

Calculates the euclidean distances from a given vector to all rows of a matrix.

Usage

1

Arguments

x

A vector[1:n] containing the data point to be compared to the Matrix.

A

A matrix[1:k,1:n] containing the data points to be compared with x.

Value

Dists

A vector[1:k] containing the distances from x to all rows of A.

Author(s)

Catharina Lippmann


Mthrun/Distances documentation built on Feb. 4, 2020, 8:39 p.m.