dist2AllRD: relative distance to all.

Description Usage Arguments Value Author(s)

View source: R/dist2AllRD.R

Description

Calculates the relative distances from a vector x to all rows of a matrix data.

Usage

1
dist2AllRD(x, data, defined)

Arguments

x

A vector to be compared to the rows of data.

data

A matrix containing the data to be compared with x as rows.

defined

A vector of the same length as x and the rows of data, containing 1 for all columns of the matrix to be used and other values for all columns to be discarded. By default all columns are used.

Value

dv

A Vector, containing the distances between x and the rows of data.

Author(s)

Raphael Paebst


Mthrun/Distances documentation built on Feb. 4, 2020, 8:39 p.m.