distancesCB: Distances (City Block)

Description Usage Arguments Value Author(s)

View source: R/distancesCB.R

Description

Calculates the distance between all rows of a matrix, using the City Block ( Manhattan) metric.

Usage

1
distancesCB(data, defined)

Arguments

data

A matrix, containing data as rows.

defined

A vector, containing 1 for all columns of data to be used and other values for all columns to be discarded.

Value

dd

A matrix containing the distances between the rows of data.

dv

A vector, containing the distances, taken from the upper triangular distance matrix.

Author(s)

Raphael Paebst


Mthrun/Distances documentation built on Feb. 4, 2020, 8:39 p.m.