squareform: Format or generate a distance matrix.

Description Usage Arguments Value Author(s)

View source: R/squareform.R

Description

Format or generate a distance matrix. uses pracmas squareform with small changes

Usage

1

Arguments

X

numeric vector or matrix

Value

y Returns a matrix if x is a vector, and a vector if x is a matrix.

Author(s)

Michael Thrun


Mthrun/Distances documentation built on Feb. 4, 2020, 8:39 p.m.