Description Usage Arguments Value Author(s)
Calculates the euclidean distances from a given vector to all rows of a matrix.
1 | dist2AllEuclid(x, A)
|
x |
A vector[1:n] containing the data point to be compared to the Matrix. |
A |
A matrix[1:k,1:n] containing the data points to be compared with x. |
Dists |
A vector[1:k] containing the distances from x to all rows of A. |
Catharina Lippmann
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.