Description Usage Arguments Value Author(s)
Calculates the distances from a vector x to all rows of a matrix, using the Minkowski 3 distance measure.
1 | dist2AllM3(x, data, defined)
|
x |
A vector of the same length as the rows of data. |
data |
A matrix, containing the data to be compared with x. |
defined |
A vector of the same length as x and the rows of data, containing 1 for all columns of the matrix to be used and other values for all columns to be discarded. By default all columns are used. |
dv |
A vector containing the distances between x and all rows of data. |
Raphael Paebst
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.