Description Usage Arguments Value Author(s)
Calculates the relative distances from a vector x to all rows of a matrix data.
1 | dist2AllRD(x, data, defined)
|
x |
A vector to be compared to the rows of data. |
data |
A matrix containing the data to be compared with x as rows. |
defined |
A vector of the same length as x and the rows of data, containing 1 for all columns of the matrix to be used and other values for all columns to be discarded. By default all columns are used. |
dv |
A Vector, containing the distances between x and the rows of data. |
Raphael Paebst
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.