Description Usage Arguments Value Author(s)
Calculates the distance between all rows of a matrix, using the City Block ( Manhattan) metric.
1 | distancesCB(data, defined)
|
data |
A matrix, containing data as rows. |
defined |
A vector, containing 1 for all columns of data to be used and other values for all columns to be discarded. |
dd |
A matrix containing the distances between the rows of data. |
dv |
A vector, containing the distances, taken from the upper triangular distance matrix. |
Raphael Paebst
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.