Description Usage Arguments Value Author(s)
Computes the k nearest neighbours to every data point.
1 | knneighbors(k, data, defined)
|
k |
The number of neighbours to be computed |
data |
A matrix containing the data points as row vectors |
defined |
A row vector, containing 1 for every column of the data to be used in the computation. If missing, all columns are used |
nn |
A matrix with n rows and k kolumns. Each row holds the k neighbours of the corresponding data point in ascending order. |
Raphael Paebst
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.