Description Usage Arguments Value Author(s)
Format or generate a distance matrix. uses pracmas squareform with small changes
1 | squareform(X)
|
X |
numeric vector or matrix |
y Returns a matrix if x is a vector, and a vector if x is a matrix.
Michael Thrun
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.